Crate numbat_wasm_serde

Crate numbat_wasm_serde 

Enums

SDError
The kind of error that can be produced during a serialization or deserialization.

Functions

bytes_to_number
Handles both signed and unsigned of any length. No generics here, because we want the executable binary as small as possible.
from_bytes
to_bytes
u64_to_bytes
Temporary solution to serialize u64 until wasm compilation issue is fixed.